@@ -2,7 +2,9 @@ from discordmenu.embed.components import EmbedFooter
 from discordmenu.embed.view_state import ViewState
 from discordmenu.intra_message_state import IntraMessageState
 
-TSUBAKI_FLOWER_ICON_URL = 'https://d1kpnpud0qoyxf.cloudfront.net/tsubaki/tsubakiflower.png'
+from ..tsubaki import CLOUDFRONT_URL
+
+TSUBAKI_FLOWER_ICON_URL = CLOUDFRONT_URL + '/tsubaki/tsubakiflower.png'
 
 
 def embed_footer():
